@@ -39,7 +39,7 @@ hhg.test = function(Dx, Dy, ties = T, w.sum = 0, w.max = 2, nr.perm = 10000,
   tables_wanted = as.integer(tables.wanted)
   perm_stats_wanted = as.integer(perm.stats.wanted)
   
-  res = .Call('HHG_R_C', test_type, Dx, Dy, dummy.y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
+  res = .Call('HHG_R_C',PACKAGE = 'HHG', test_type, Dx, Dy, dummy.y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
   ret = .organize.results(res, n = nrow(Dx), nr.perm, tables.wanted, perm.stats.wanted, grid.len = 0)
   
   class(ret) = 'HHG.Test.Result'
@@ -102,7 +102,7 @@ hhg.test.k.sample = function(Dx, y, w.sum = 0, w.max = 2, nr.perm = 10000,
   tables_wanted = as.integer(tables.wanted)
   perm_stats_wanted = as.integer(perm.stats.wanted)
     
-  res = .Call('HHG_R_C', test_type, Dx, dummy.Dy, y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
+  res = .Call('HHG_R_C',PACKAGE = 'HHG', test_type, Dx, dummy.Dy, y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
   ret = .organize.results(res, n = nrow(Dx), nr.perm, tables.wanted, perm.stats.wanted, grid.len = 0)
   
   class(ret) = 'HHG.Test.Result'
@@ -161,7 +161,7 @@ hhg.test.2.sample = function(Dx, y, w.sum = 0, w.max = 2, nr.perm = 10000,
   tables_wanted = as.integer(tables.wanted)
   perm_stats_wanted = as.integer(perm.stats.wanted)
     
-  res = .Call('HHG_R_C', test_type, Dx, dummy.Dy, y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
+  res = .Call('HHG_R_C',PACKAGE = 'HHG', test_type, Dx, dummy.Dy, y, w.sum, w.max, extra_params, is_sequential, alpha_hyp, alpha0, beta0, eps, nr_perm, nr_threads, tables_wanted, perm_stats_wanted)
   ret = .organize.results(res, n = nrow(Dx), nr.perm, tables.wanted, perm.stats.wanted, grid.len = 0)
   
   class(ret) = 'HHG.Test.Result'
